/*-------------------------------------------------------------------------
 *
 * LightDB统一SQL转换库接口头文件
 * 
 *
 * Portions Copyright (c) 2024,  Hundsun Technologies, Inc.
 *
 *-------------------------------------------------------------------------
 */

#ifndef __UNSIQL_H__
#define __UNSIQL_H__



#ifdef __cplusplus
extern "C" {
#endif



#define UNISQL_DBTYPE_LIGHTDB_MYSQL         1  // LIGHTDB MYSQL模式
#define UNISQL_DBTYPE_LIGHTDB_ORACLE        2  // LIGHTDB ORACLE模式
#define UNISQL_DBTYPE_LIGHTDB_POSTGRESQL    3  // LIGHTDB POSTGRESQL模式
#define UNISQL_DBTYPE_DM                    4  // 达梦
#define UNISQL_DBTYPE_MYSQL                 5  // MYSQL
#define UNISQL_DBTYPE_TDSQL_MYSQL           6  // TDSQL MYSQL模式
#define UNISQL_DBTYPE_MYSQL_80              7  // MYSQL8
#define UNISQL_DBTYPE_OCEAN_BASE_MYSQL      8  // OceanBase MYSQL模式
#define UNISQL_DBTYPE_OCEAN_BASE_ORACLE     9  // OceanBase ORACLE模式
#define UNISQL_DBTYPE_OPENGAUSS             10 // OPENGAUSS
#define UNISQL_DBTYPE_ORACLE                11 // ORACLE
#define UNISQL_DBTYPE_POSTGRESQL            12 // POSTGRESQL
#define UNISQL_DBTYPE_GOLDENDB_MYSQL        13 // GOLDENDB MYSQL模式
#define UNISQL_DBTYPE_GOLDENDB_ORACLE       14 // GOLDENDB ORACLE模式
#define UNISQL_DBTYPE_GAUSSDB_MYSQL         15 // 高斯 MYSQL模式
#define UNISQL_DBTYPE_GAUSSDB_ORACLE        16 // 高斯 ORACLE模式
#define UNISQL_DBTYPE_SQLSVR                17 // SQLSVR模式
#define UNISQL_DBTYPE_TDSQL_PG_ORACLE       18 // tdsql_pg oracle模式
#define UNISQL_DBTYPE_GAUSSDB500_ORACLE     19 // 高斯 ORACLE模式，(GaussDB Kernel V500R002C10 build f6002322)版本


/**
 * 释放内存
 */
extern void FreePointer(void* c);
/**
 * 设置还原参数
 * @param n 选项集合的整数表示
 */
extern void SetRestoreFormat(long int n);
/**
 * 设置全局参数，参数格式为json字符串
 * @param globalStaticParameterJson json格式的输入参数，包含可设置的所有选项
 */
extern void SetGlobalStaticParameter(const char* globalStaticParameterJson);
/**
 * 转换单条SQL语句
 * @param csql 源SQL语句
 * @param sourceDialect 源数据库方言
 * @param targetDialect 目标数据库方言
 */
extern char* Transform(const char* csql, const char* sourceDialect, const char* targetDialect);
/**
 * 转换单条SQL语句
 * @param jsonParameter json格式的输入参数，包含源SQL、源数据库方言、源数据库方言即其他选项参数
 */
extern char* TransformPro(const char* jsonParameter);
/**
 * 转换单条SQL语句
 * @param sourceDbTypeCode 源数据库方言编码(见UNISQL_DBTYPE_定义)
 * @param targetDbTypeCode 目标数据库方言编码(见UNISQL_DBTYPE_定义)
 * @param sourceSqlStr 源SQL语句
 * @param targetSqlStr 转换后的SQL语句
 * @param targetSqlStrLen 转换后的SQL长度
 * @param jsonParameter json格式的选项
 */
extern int TransferSQL(
        int sourceDbTypeCode, 
        int targetDbTypeCode, 
        const char* sourceSqlStr, 
        char* targetSqlStr, 
        int targetSqlStrLen, 
        const char* jsonParameter);
/**
 * 设置垃圾收集目标百分比
 * @param n 百分比值
 */
extern void SetGoGc(long int n);
/**
 * 设置垃圾收集的软内存限制
 * @param n 内存值
 */
extern void SetGoMemLimit(long int n);
/**
 * 获取insert、update、delete的前后查询SQL，用于多发比对
 * @param jsonParameter json格式的参数集合
 */
extern char* GetDqlByDml(const char* jsonParameter);
/**
 * 校验go模块版本号是否和输入的版本号version一致，一致则返回00000，否则返回错误提示
 * @param 预期版本号
 */
extern char* CheckIterationVersion(const char* version);
/**
 * 设置多发比对的表元数据，用于忽略查询字段
 * @param jsonParameter json格式的参数集合
 */
extern char* InitTableMetas(const char* jsonParameter);
/**
 * 设置表列元数据，用于转换过程中的特殊处理，如改写 replace into
 * @param jsonParameter json格式的参数集合
 */
extern char* InitTableColumnMetas(const char* jsonParameter);

#ifdef __cplusplus
}
#endif

#endif 
